==> sammaadmin-1.00.tar.gz: htdocs/admin/postldapadmin/samma/tmpl/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ƥץ졼Խ
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.9 $
 * $Date: 2010/06/28 07:57:34 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION",  "ƥץ졼Խ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;
        global $templ_data;

        /* html */
        $cnv_templ_data = htmlspecialchars($templ_data);

        print <<<EOD
<script type="text/javascript">
<!--
  function resultwindow() {
      window.open("", "helpwindow", "width=600,height=270");
      document.help.target = "helpwindow";
      document.help.submit();
  }
// -->
</script>

<form method="post" action="index.php" name="templ_mod">
  <table class="table">
    <tbody>
      <tr>
        <td class="key1">Υ᡼ƥץ졼</td>
        <td class="value">
          <textarea name="templ_data" cols=45 rows=15>$cnv_templ_data</textarea>
        </td>
      </tr>
    </tbody>
  </table>
  <br>
<table>
  <td>
  <input type="hidden" name="sk" value="$sesskey">
  <input type="submit" name="mod" value="" class="mod_btn">
  <input type="submit" name="cancel" value="" class="cancel_btn">
  </td>
</form>
<form method="post" name="help" action="help.php">
  <td>
  <input type="hidden" name="sk" value="$sesskey">
  <input type="submit" name="help" value="" class="help_btn" onClick="resultwindow()">
  </td>
</form>
</table>
EOD;
    }
}

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg = new my_page();

/* ͤν */
$err_msg = "";
$templ_data = "";

/* POSTͤ */
if (isset($_POST["templ_data"]) === TRUE) {
    $templ_data = $_POST["templ_data"];
}

/* ե롦ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/* SaMMAեɹ */
$ret = read_samma_conf($web_conf["postldapadmin"]["sammaconf"]);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/* commandpass */
if (isset($samma_conf["commandpass"]) === TRUE) {
    $commandpass = $samma_conf["commandpass"];
}

/***********************************************************
 * main
 **********************************************************/

/* ѹܥ󤬲줿Ȥ */
if (isset($_POST["mod"]) === TRUE) {

    /* ϥå */
    if (empty($templ_data) === TRUE) {
        $err_msg = "Υ᡼ƥץ졼ȤϤƤޤ";
        result_log(OPERATION . ":OK:" . $err_msg);
    } else {
        /* ƥץ졼ȥեν񤭴 */
        $ret = write_file($samma_conf["templatepath"], STRCODE, $templ_data);
        if ($ret === FALSE) {
            result_log(OPERATION . ":NG:" . $err_msg);
        } else {
            /* sammaƥץ졼ȤΥ */
            $ret = reload_samma(TEMPLATE);
            if ($ret === FALSE) {
                result_log(OPERATION . ":NG:" . $err_msg);
            } else {
                /* ｪλ */
                $err_msg = "ƥץ졼Ȥ򹹿ޤ";
                result_log(OPERATION . ":OK:" . $err_msg);

                /* SaMMA˥塼̤ */
                dgp_location("../index.php", $err_msg);
                exit(0);
            }
        }
    }

/* 󥻥ܥ󤬲줿Ȥ */
} elseif (isset($_POST["cancel"]) === TRUE) {

    /* SaMMA˥塼̤ */
    dgp_location("../index.php", $err_msg);
    exit(0);
}

/* ɽ */
if (isset($_POST["templ_data"]) === FALSE) {

    /* ƥץ졼ȥեɤ߹ */
    $ret = read_file($samma_conf["templatepath"], $templ_data);
    if ($ret === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
        $sys_err = TRUE;
        $pg->display(NULL);
        exit (1);
    }
}

/***********************************************************
 * ɽ
 **********************************************************/

$pg->display(CONTENT);
?>

==> sammaadmin-2.00.tar.gz: htdocs/admin/postldapadmin/samma/tmpl/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ƥץ졼Խ
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.10 $
 * $Date: 2013/08/30 06:21:54 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION",  "ƥץ졼Խ");
define("TMPLFILE", "samma/samma_admin_tmpl.tmpl");

/***********************************************************
 * ؿ
 **********************************************************/
/***********************************************************
 * set_tag_data()
 *
 * ֤ξ򥻥åȤ
 *
 * []
 *      $tag  ֤
 *
 * [֤]
 *       ʤ
 **********************************************************/
function set_tag_data(&$tag) {

    global $sesskey;
    global $templ_data;

    /* html */
    $cnv_templ_data = htmlspecialchars($templ_data);
    $tag["<<CNV_TMPL_DATA>>"] = $cnv_templ_data;

    return TRUE;

}

/***********************************************************
 * 
 **********************************************************/
/* ͤν */
$err_msg = "";
$templ_data = "";
$tag = array();

/* POSTͤ */
if (isset($_POST["templ_data"]) === TRUE) {
    $templ_data = $_POST["templ_data"];
}
/* å󥭡ѿ */
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롦ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    syserr_display();
    exit (1);
}

/* SaMMAեɹ */
$ret = read_samma_conf($web_conf["postldapadmin"]["sammaconf"]);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    syserr_display();
    exit (1);
}

/* commandpass */
if (isset($samma_conf["commandpass"]) === TRUE) {
    $commandpass = $samma_conf["commandpass"];
}

/***********************************************************
 * main
 **********************************************************/

/* ѹܥ󤬲줿Ȥ */
if (isset($_POST["mod"]) === TRUE) {

    /* ϥå */
    if (empty($templ_data) === TRUE) {
        $err_msg = "Υ᡼ƥץ졼ȤϤƤޤ";
        result_log(OPERATION . ":OK:" . $err_msg);
    } else {
        /* ƥץ졼ȥեν񤭴 */
        $ret = write_file($samma_conf["templatepath"], STRCODE, $templ_data);
        if ($ret === FALSE) {
            result_log(OPERATION . ":NG:" . $err_msg);
        } else {
            /* sammaƥץ졼ȤΥ */
            $ret = reload_samma(TEMPLATE);
            if ($ret === FALSE) {
                result_log(OPERATION . ":NG:" . $err_msg);
            } else {
                /* ｪλ */
                $err_msg = "ƥץ졼Ȥ򹹿ޤ";
                result_log(OPERATION . ":OK:" . $err_msg);

                /* SaMMA˥塼̤ */
                dgp_location("../index.php", $err_msg);
                exit(0);
            }
        }
    }

/* 󥻥ܥ󤬲줿Ȥ */
} elseif (isset($_POST["cancel"]) === TRUE) {

    /* SaMMA˥塼̤ */
    dgp_location("../index.php", $err_msg);
    exit(0);
}

/* ɽ */
if (isset($_POST["templ_data"]) === FALSE) {

    /* ƥץ졼ȥեɤ߹ */
    $ret = read_file($samma_conf["templatepath"], $templ_data);
    if ($ret === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
        syserr_display();
        exit (1);
    }
}

/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

set_tag_data($tag);

/* ڡν */
$ret = display(TMPLFILE, $tag, array(), "", "");
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
